==> sceditor-8.x-1.1.tar.gz: sceditor/src/Controller/SCEditorController.php <==
<?php

namespace Drupal\sceditor\Controller;

use Drupal\Core\Controller\ControllerBase;

/**
 * Class SCEditorController.
 */
class SCEditorController extends ControllerBase {

  /**
   * Sceditorpage.
   *
   * @return string
   *   Return Hello string.
   */
  public function scEditorPage() {
    \Drupal::service('page_cache_kill_switch')->trigger();
    $this->checkFTPStatus();
    $root = DRUPAL_ROOT;
    $path = null;
    $links = [];
    if (isset($_GET['file'])) {
      if ($_GET['file'] == 'clear') {
        shell_exec('git checkout .');
      }
      $path = $_GET['file'];
      if (!$this->isInDirectory($_GET['file'], $root)) {
        $path = null;
      }
      else {
        $path = '/' . $path;
      }
    }
    $url = $root . $path;
    if (is_file($url)) {
      if (!empty($_POST['file_content'])) {
        $config = \Drupal::config('sceditor.ftpaccess');
        $ftp_server = $config->get('host');
        $ftp_user = $config->get('username');
        $ftp_pass = $config->get('password');
        $module_path = drupal_get_path('module', 'sceditor');
        $ftp_save = TRUE;
        if ($ftp = ftp_connect($ftp_server)) {
          if (ftp_login($ftp, $ftp_user, $ftp_pass)) {
            file_put_contents($module_path . '/temp/temp.txt', $_POST['file_content']);
            if (ftp_put($ftp, $url, $module_path . '/temp/temp.txt', FTP_BINARY)) {
              ftp_close($ftp);
            }
            else {
              $ftp_save = FALSE;
            }
          }
          else {
            $ftp_save = FALSE;
          }
        }
        else {
          $ftp_save = FALSE;
        }
        // If FTP not available, then save regularly.
        if ($ftp_save == FALSE) {
          file_put_contents($url, $_POST['file_content']);
        }
      }

      $data = file_get_contents($url);
      $extension = explode('.', $path);
      $build = [
        '#theme' => 'sceditor',
        '#ext' => end($extension),
        '#link' => urlencode($path),
        '#return' => urlencode(substr(dirname($url), strlen($root) + 1)),
        '#data' => $data,
        '#attached' => [
          'library' => [
            'sceditor/sceditor.styles',
            'sceditor/sceditor.customjs',
          ],
        ],
      ];
      $build['#attached']['drupalSettings']['sceditor']['ext'] = end($extension);
      return $build;
    }

    if ($path) {
      $links[] = [
        'size' => '-',
        'time' => '-',
        'type' => '<i class="fa fa-level-up fa-fw"></i>',
        'link' => urlencode(substr(dirname($url), strlen($root) + 1)),
        'name' => '..',
      ];
    }
    foreach (glob($root . $path . '/*') as $file) {
      $file = realpath($file);
      $link = substr($file, strlen($root) + 1);
      $links[] = [
        'size' => (is_dir($file)) ? '-' : round(filesize($file) / 1024, 2),
        'time' => date("F d Y H:i:s", filemtime($file)),
        'type' => (is_dir($file)) ? '<i class="fa fa-folder fa-fw"></i>' : '<i class="fa fa-file-text fa-fw"></i>',
        'link' => urlencode($link),
        'name' => basename($file),
      ];
    }
    $build = [
      '#theme' => 'sceditor_directories',
      '#links' => $links,
      '#attached' => [
        'library' => [
          'sceditor/sceditor.styles',
        ],
      ],
    ];
    $build['#attached']['drupalSettings']['sceditor']['ext'] = 'dir';
    return $build;

  }

  /**
   * Check if in directory.
   *
   * @param $file
   *   The filename.
   * @param $directory
   *   The root directory.
   * @param bool $recursive
   *   Whether recursive or not.
   *
   * @return bool
   */
  public function isInDirectory($file, $directory, $recursive = TRUE) {
    $directory = realpath($directory);
    $parent = realpath($file);
    while ($parent) {
      if ($directory == $parent) {
        return TRUE;
      }
      if ($parent == dirname($parent) || !$recursive) {
        break;
      }
      $parent = dirname($parent);
    }
    return FALSE;
  }

  /**
   * Check id the FTP Access is available.
   */
  public function checkFTPStatus() {
    $config = \Drupal::config('sceditor.ftpaccess');
    $ftp_server = $config->get('host');
    $ftp_user = $config->get('username');
    $ftp_pass = $config->get('password');
    $ftp = (empty($ftp_server)) ? FALSE : ftp_connect($ftp_server);
    if (!$ftp || !ftp_login($ftp, $ftp_user, $ftp_pass)) {
      drupal_set_message($this->t('FTP is not connected. If you want to edit using FTP, please check your FTP Credentials <a href="/admin/config/sceditor/ftpaccess" target="_blank">here</a>.'), 'warning');
    }
  }

}

==> sceditor-8.x-1.2.tar.gz: sceditor/src/Controller/SCEditorController.php <==
<?php

namespace Drupal\sceditor\Controller;

use Drupal\Core\Controller\ControllerBase;

/**
 * Class SCEditorController.
 */
class SCEditorController extends ControllerBase {

  /**
   * Sceditorpage.
   *
   * @return string
   *   Return Hello string.
   */
  public function scEditorPage() {
    \Drupal::service('page_cache_kill_switch')->trigger(); // @codingStandardsIgnoreLine
    $this->checkFtpStatus();
    $root = DRUPAL_ROOT;
    $path = NULL;
    $links = [];
    if (isset($_GET['file'])) {
      if ($_GET['file'] == 'clear') {
        shell_exec('git checkout .');
      }
      $path = $_GET['file'];
      if (!$this->isInDirectory($_GET['file'], $root)) {
        $path = NULL;
      }
      else {
        $path = '/' . $path;
      }
    }
    $url = $root . $path;
    if (is_file($url)) {
      if (!empty($_POST['file_content'])) {
        $config = \Drupal::config('sceditor.ftpaccess'); // @codingStandardsIgnoreLine
        $ftp_server = $config->get('host');
        $ftp_user = $config->get('username');
        $ftp_pass = $config->get('password');
        $module_path = drupal_get_path('module', 'sceditor');
        $ftp_save = TRUE;
        if ($ftp = ftp_connect($ftp_server)) {
          if (ftp_login($ftp, $ftp_user, $ftp_pass)) {
            file_put_contents($module_path . '/temp/temp.txt', $_POST['file_content']);
            if (ftp_put($ftp, $url, $module_path . '/temp/temp.txt', FTP_BINARY)) {
              ftp_close($ftp);
            }
            else {
              $ftp_save = FALSE;
            }
          }
          else {
            $ftp_save = FALSE;
          }
        }
        else {
          $ftp_save = FALSE;
        }
        // If FTP not available, then save regularly.
        if ($ftp_save == FALSE) {
          file_put_contents($url, $_POST['file_content']);
        }
      }

      $data = file_get_contents($url);
      $extension = explode('.', $path);
      $build = [
        '#theme' => 'sceditor',
        '#ext' => end($extension),
        '#link' => urlencode($path),
        '#return' => urlencode(substr(dirname($url), strlen($root) + 1)),
        '#data' => $data,
        '#attached' => [
          'library' => [
            'sceditor/sceditor.styles',
            'sceditor/sceditor.customjs',
          ],
        ],
      ];
      $build['#attached']['drupalSettings']['sceditor']['ext'] = end($extension);
      return $build;
    }

    if ($path) {
      $links[] = [
        'size' => '-',
        'time' => '-',
        'type' => '<i class="fa fa-level-up fa-fw"></i>',
        'link' => urlencode(substr(dirname($url), strlen($root) + 1)),
        'name' => '..',
      ];
    }
    foreach (glob($root . $path . '/*') as $file) {
      $file = realpath($file);
      $link = substr($file, strlen($root) + 1);
      $links[] = [
        'size' => (is_dir($file)) ? '-' : round(filesize($file) / 1024, 2),
        'time' => date("F d Y H:i:s", filemtime($file)),
        'type' => (is_dir($file)) ? '<i class="fa fa-folder fa-fw"></i>' : '<i class="fa fa-file-text fa-fw"></i>',
        'link' => urlencode($link),
        'name' => basename($file),
      ];
    }
    $build = [
      '#theme' => 'sceditor_directories',
      '#links' => $links,
      '#attached' => [
        'library' => [
          'sceditor/sceditor.styles',
        ],
      ],
    ];
    $build['#attached']['drupalSettings']['sceditor']['ext'] = 'dir';
    return $build;

  }

  /**
   * Check if in directory.
   *
   * @param string $file
   *   The filename.
   * @param string $directory
   *   The root directory.
   * @param bool $recursive
   *   Whether recursive or not.
   *
   * @return bool
   *   TRUE is in directory, FALSE if not.
   */
  public function isInDirectory($file, $directory, $recursive = TRUE) {
    $directory = realpath($directory);
    $parent = realpath($file);
    while ($parent) {
      if ($directory == $parent) {
        return TRUE;
      }
      if ($parent == dirname($parent) || !$recursive) {
        break;
      }
      $parent = dirname($parent);
    }
    return FALSE;
  }

  /**
   * Check id the FTP Access is available.
   */
  public function checkFtpStatus() {
    $config = \Drupal::config('sceditor.ftpaccess'); // @codingStandardsIgnoreLine
    $ftp_server = $config->get('host');
    $ftp_user = $config->get('username');
    $ftp_pass = $config->get('password');
    $ftp = (empty($ftp_server)) ? FALSE : ftp_connect($ftp_server);
    if (!$ftp || !ftp_login($ftp, $ftp_user, $ftp_pass)) {
      drupal_set_message($this->t('FTP is not connected. If you want to edit using FTP, please check your FTP Credentials <a href="/admin/config/sceditor/ftpaccess" target="_blank">here</a>.'), 'warning');
    }
  }

}
